# ``carculator_utils``


Base classes and functions for the carculator package suite.
Provides base classes to:

* carculator
* carculator_bus
* carculator_truck
* carculator_two-wheeler

## Support

Do not hesitate to contact the development team at [carculator@psi.ch](mailto:carculator@psi.ch).

## Maintainers

* [Romain Sacchi](https://github.com/romainsacchi)

## Contributing

See [contributing](https://github.com/romainsacchi/carculator_utils/blob/master/CONTRIBUTING.md).

## License

[BSD-3-Clause](https://github.com/romainsacchi/carculator_utils/blob/master/LICENSE). Copyright 2023 Paul Scherrer Institut.
